=====
TODOs
=====


* Support all known htpasswd hash formats

* When stopping the ejabber daemon, squelch the ``error: unpack
  requires a string argument of length 2`` error

* **Optionally** support the ``setpass`` command
